/**
 * Deep copy an object
 */
export declare function deepCopyObject<O extends object>(copyObject: O): O;
export declare function hasOwnProperty(scope: any, prop: string): boolean;
type GetPath = string | number | (string | number)[];
/**
 * Safely retrieves a value from a nested object using a path.
 */
export declare const get: <T extends object, D = undefined>(obj: T | null | undefined, path: GetPath, defValue?: D) => D | undefined | any;
/**
 * Retrieves a value from an object using a property path, with support for fallback paths.
 * When given an array of paths, returns the first non-empty value found.
 *
 * @param object - The source object to extract the value from
 * @param propertyPath - Either a single string path or an array of string paths to try in order
 * @param defaultValue - Value to return if no non-empty value is found
 * @returns The first non-empty value found, or the default value if none found
 */
export declare function getPropertyValue(object: any, propertyPath: string | string[], defaultValue?: any): any;
declare const _default: {
    deepCopyObject: typeof deepCopyObject;
    hasOwnProperty: typeof hasOwnProperty;
    get: <T extends object, D = undefined>(obj: T | null | undefined, path: GetPath, defValue?: D) => D | undefined | any;
    getPropertyValue: typeof getPropertyValue;
};
export default _default;
